﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Data;
using System.Collections.ObjectModel;
using System.Diagnostics;
using Infragistics;
using System.ComponentModel;
using Infragistics.Controls.Schedules;

namespace TestProject
{
	/// <summary>
	/// Interaction logic for MainWindow.xaml
	/// </summary>
	public partial class MainWindow : Window
	{
		public MainWindow()
		{
			var sd = new ScheduleData();
			sd.Resources.Add(new ResourceDataItem { Id = "res0", Name = "Resource 0" });
			sd.Resources.Add(new ResourceDataItem { Id = "res1", Name = "Resource 1" });

			sd.Calendars.Add(new ResourceCalendarDataItem { Id = "cal0", OwningResourceId = "res0", Name = "Main", BaseColor = Colors.Red });
			sd.Calendars.Add(new ResourceCalendarDataItem { Id = "cal1", OwningResourceId = "res1", Name = "Main", BaseColor = Colors.Blue });

			sd.CurrentUserId = "res0";

			this.DataContext = sd;

			InitializeComponent();

			this.dm.CalendarGroups.Add(new CalendarGroup { InitialCalendarIds = "res0[cal0], res1[cal1]" });
		}
	}

	public class ScheduleData : DataItemBase
	{
		private ObservableCollection<ResourceDataItem> _resources;
		private ObservableCollection<ResourceCalendarDataItem> _calendars;

		public ScheduleData()
		{
			_resources = new ObservableCollection<ResourceDataItem>();
			_calendars = new ObservableCollection<ResourceCalendarDataItem>();
		}

		public IList<ResourceDataItem> Resources
		{
			get { return _resources; }
		}

		public IList<ResourceCalendarDataItem> Calendars
		{
			get { return _calendars; }
		}

		private string _currentUserId;
		public string CurrentUserId
		{
			get { return _currentUserId; }
			set { this.SetField(ref _currentUserId, value, "CurrentUserId"); }
		}
		
	}

	public class DataItemBase : INotifyPropertyChanged
	{
		protected bool SetField<T>(ref T member, T value, string propertyName)
		{
			if (EqualityComparer<T>.Default.Equals(member, value))
				return false;

			member = value;
			this.OnPropertyChanged(propertyName);
			return true;
		}

		protected void OnPropertyChanged(string propertyName)
		{
			var handler = this.PropertyChanged;

			if (null != handler)
				handler(this, new PropertyChangedEventArgs(propertyName));
		}

		public event PropertyChangedEventHandler PropertyChanged;
	}

	public class ResourceDataItem : DataItemBase
	{
		private string _id;
		public string Id
		{
			get { return _id; }
			set { this.SetField(ref _id, value, "Id"); }
		}

		private string _name;
		public string Name
		{
			get { return _name; }
			set { this.SetField(ref _name, value, "Name"); }
		}
	}

	public class ResourceCalendarDataItem : DataItemBase
	{
		private string _id;
		public string Id
		{
			get { return _id; }
			set { this.SetField(ref _id, value, "Id"); }
		}

		private string _owningResourceId;
		public string OwningResourceId
		{
			get { return _owningResourceId; }
			set { this.SetField(ref _owningResourceId, value, "OwningResourceId"); }
		}

		private string _name;
		public string Name
		{
			get { return _name; }
			set { this.SetField(ref _name, value, "Name"); }
		}

		private Color _baseColor;
		public Color BaseColor
		{
			get { return _baseColor; }
			set { this.SetField(ref _baseColor, value, "BaseColor"); }
		}
	}

}
